@@ -76,6 +76,15 @@ def update_schemes_stats(kdamond_idxs):
             return err
     return None
 
+'Return error'
+def update_schemes_tried_bytes(kdamond_idxs):
+    for kdamond_idx in kdamond_idxs:
+        err = _damo_fs.write_file(
+                state_file_of(kdamond_idx), 'update_schemes_tried_bytes')
+        if err != None:
+            return err
+    return None
+
 'Return error'
 def update_schemes_tried_regions(kdamond_idxs):
     for kdamond_idx in kdamond_idxs:
@@ -88,12 +97,18 @@ def update_schemes_tried_regions(kdamond_idxs):
 # for stage_kdamonds
 
 def wops_for_scheme_filter(damos_filter):
-    return {
+    wops = {
         'type': '%s' % damos_filter.filter_type,
         'memcg_path': ('%s' % damos_filter.memcg_path
             if damos_filter.memcg_path != None else ''),
         'matching': 'Y' if damos_filter.matching else 'N',
         }
+    if damos_filter.address_range != None:
+        wops['addr_start'] = '%d' % damos_filter.address_range.start
+        wops['addr_end'] = '%d' % damos_filter.address_range.end
+    if damos_filter.damon_target_idx != None:
+        wops['damon_target_idx'] = '%d' % damos_filter.damon_target_idx
+    return wops
 
 def wops_for_scheme_filters(filters):
     wops = {}
@@ -347,7 +362,14 @@ def files_content_to_watermarks(files_content):
 
 def files_content_to_damos_filters(files_content):
     return [_damon.DamosFilter(filter_kv['type'].strip(),
-            filter_kv['memcg_path'].strip(), filter_kv['matching'].strip())
+            filter_kv['matching'].strip(),
+            filter_kv['memcg_path'].strip(),
+            _damon.DamonRegion(filter_kv['addr_start'].strip(),
+                filter_kv['addr_end'].strip())
+                if 'addr_start' in filter_kv and 'addr_end' in filter_kv
+                else None,
+            filter_kv['damon_target_idx']
+                if 'damon_target_idx' in filter_kv else None)
             for filter_kv in numbered_dirs_content(
                 files_content, 'nr_filters')]
 
@@ -377,7 +399,10 @@ def files_content_to_scheme(files_content):
             files_content_to_damos_stats(files_content['stats']),
             files_content_to_damos_tried_regions(
                 files_content['tried_regions'])
-                if 'tried_regions' in files_content else [])
+                if 'tried_regions' in files_content else [],
+            files_content['tried_regions']['total_bytes']
+                if 'tried_regions' in files_content and
+                    'total_bytes' in files_content['tried_regions'] else None)
 
 def files_content_to_regions(files_content):
     return [_damon.DamonRegion(
