@@ -8,7 +8,9 @@ import _damon
 import _damon_args
 
 def set_argparser(parser):
-    return _damon_args.set_common_argparser(parser)
+    _damon_args.set_common_argparser(parser)
+    parser.description='Stop DAMON'
+    return parser
 
 def main(args=None):
     if not args:
